@@ -27,7 +27,7 @@ static int gCmdLineCompletionMaxRow;
 static int gCompletionScrollTop = 0;
 static int gCompletionCursor = -1;
 
-vector_obj* gEnvirons;             // ϐ⊮
+vector_obj* gEnvirons;             // 環境変数補完候補
 
 static BOOL name_sort(void* left, void* right)
 {
@@ -39,7 +39,7 @@ static BOOL name_sort(void* left, void* right)
 
 
 ///////////////////////////////////////////////////
-// 
+// 初期化
 ///////////////////////////////////////////////////
 void cmdline_completion_init()
 {
@@ -84,7 +84,7 @@ void cmdline_completion_final()
         string_delete(vector_item(gCCandidate, i));
     }
     vector_delete(gCCandidate);
-    for(i=0; i<vector_size(gCCandidate); i++) {
+    for(i=0; i<vector_size(gCExplanation); i++) {
         string_delete(vector_item(gCExplanation, i));
     }
     vector_delete(gCExplanation);
@@ -96,7 +96,7 @@ void cmdline_completion_final()
 }
 
 ///////////////////////////////////////////////////
-// R}hC⊮NA
+// コマンドライン補完候補クリア
 ///////////////////////////////////////////////////
 void cmdline_completion_clear()
 {
@@ -112,7 +112,7 @@ void cmdline_completion_clear()
 }
 
 ///////////////////////////////////////////////////
-// R}hC⊮1
+// コマンドライン補完1
 ///////////////////////////////////////////////////
 void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space)
 {
@@ -241,7 +241,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
 }
 
 ///////////////////////////////////////////////////
-// R}hC⊮2
+// コマンドライン補完2
 ///////////////////////////////////////////////////
 void cmdline_completion2(vector_obj* all_candidate, char* editing, BOOL add_space, int candidate_len)
 {
@@ -374,16 +374,16 @@ void cmdline_completion2(vector_obj* all_candidate, char* editing, BOOL add_spac
 }
 
 ///////////////////////////////////////////////////
-// t@C̕⊮
+// ファイル名の補完
 ///////////////////////////////////////////////////
 void cmdline_completion_file(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
     char editing_dir2[kCmdLineMax];
     strcpy(editing_dir2, editing_dir);
 
-    /// editing_dir݂Ȃ ///
+    /// editing_dirが存在するなら ///
     if(strcmp(editing_dir2, "") != 0) {
-        /// ϐn܂Ăꍇ ///
+        /// 環境変数から始まっている場合 ///
         if(editing_dir2[0] == '$') {
             char new_editing_dir[kCmdLineMax];
             char env_name[256];
@@ -409,7 +409,7 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             }
         }
 
-        /// `_n܂Ăꍇ ///
+        /// チルダから始まっている場合 ///
         else if(editing_dir2[0] == '~') {
             char new_editing_dir[kCmdLineMax];
 
@@ -513,7 +513,7 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
 }
 
 ///////////////////////////////////////////////////
-// vO̕⊮
+// プログラム名の補完
 ///////////////////////////////////////////////////
 void cmdline_completion_program(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
@@ -526,7 +526,7 @@ void cmdline_completion_program(char* editing_dir, char* editing_file, char* edi
 }
 
 ///////////////////////////////////////////////////
-// R}hCp[X
+// コマンドラインをパース
 ///////////////////////////////////////////////////
 void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* editing_dir, char* editing_file, int* editing_position, vector_obj** earray, BOOL* squote, BOOL* dquote, BOOL* last_squote, BOOL* last_dquote)
 {
@@ -675,7 +675,7 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 }
 
 ///////////////////////////////////////////////////
-// R}hCŃ^uꂽ̏
+// コマンドラインでタブが押された時の処理
 ///////////////////////////////////////////////////
 void cmdline_completion_main()
 {
@@ -687,7 +687,7 @@ void cmdline_completion_main()
         gCompletionCursor = 0;
     }
     else {
-        /// R}hCp[X ///
+        /// コマンドラインパース ///
         int editing_position;
         char cmdname[kCmdLineMax];
         char editing[kCmdLineMax];
@@ -718,7 +718,7 @@ void cmdline_completion_main()
                                     , editing_position);
         }
 
-        /// gCmdLineCompletionMaxRow𓾂 ///
+        /// gCmdLineCompletionMaxRowを得る ///
         const int maxx = mgetmaxx();
         const int maxy = mgetmaxy();
 
@@ -740,7 +740,7 @@ void cmdline_completion_main()
 }
 
 ///////////////////////////////////////////////////
-// `
+// 描写
 ///////////////////////////////////////////////////
 void cmdline_completion_view()
 {
@@ -849,7 +849,7 @@ void cmdline_completion_view()
 }
 
 ///////////////////////////////////////////////////
-// ͏
+// 入力処理
 ///////////////////////////////////////////////////
 void cmdline_completion_input(int meta, int key)
 {
@@ -933,7 +933,7 @@ void cmdline_completion_input(int meta, int key)
         string_obj* str = gCmdLine;
         char* cstr = string_c_str(str);
 
-        /// ⊮} ///
+        /// 補完文字列を挿入 ///
         string_insert(str, gCmdLineCursor, tmp);
         gCmdLineCursor+=strlen(tmp);
 
