@@ -33,15 +33,19 @@
 #ifdef __LINUX__
 
 #include <linux/limits.h>
+/*
 #define __USE_POSIX
 #define __USE_XOPEN_EXTENDED
 #define __USE_POSIX199309
 #define __USE_UNIX98
+*/
 #include <signal.h>
+/*
 #undef __USE_POSIX
 #undef __USE_XOPEN_EXTENDED
 #undef __USE_POSIX199309
 #undef __USE_UNIX98
+*/
 #include <sys/wait.h>
 
 #else
@@ -118,10 +122,10 @@ static void job_view()
     const int maxy = mgetmaxy();
     const int maxx = mgetmaxx();
 
-    const int size = kitutuki_job_num();
+    const int size = saphire_job_num();
     int i;
     for(i=0; i<size; i++) {
-        char* title = kitutuki_job_title(i);
+        char* title = saphire_job_title(i);
 
         const int x = (maxx/size)*i;
         char buf[BUFSIZ];
@@ -190,30 +194,40 @@ static void read_rc_file_compiled()
 {
     char rc_fname[256];
 
-    sprintf(rc_fname, "%s/mfiler3.kio", gHomeDir);
+    sprintf(rc_fname, "%s/mfiler3.sao", gHomeDir);
 
     if(access(rc_fname, R_OK) == 0) {
-        int rcode = kitutuki_load_obj(rc_fname
-            , STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+        sRFd* pipein = sRFd_new(STDIN_FILENO);
+        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        int rcode = saphire_load_obj(rc_fname
+            , pipeout, pipein, STDERR_FILENO);
+        sRFd_delete(pipein);
+        sWFd_flash(pipeout);
+        sWFd_delete(pipeout);
         if(rcode < 0) {
-            fprintf(stderr, "%s\n", gErrMsg);
+            fprintf(stderr, "%s\n", string_c_str(gErrMsg));
             exit(1);
         }
     }
     else {
-        sprintf(rc_fname,"%s/mfiler3.kio", SYSCONFDIR);
+        sprintf(rc_fname,"%s/mfiler3.sao", SYSCONFDIR);
 
         if(access(rc_fname, R_OK) == 0) {
-            int rcode = kitutuki_load_obj(rc_fname
-                , STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+            sRFd* pipein = sRFd_new(STDIN_FILENO);
+            sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+            int rcode = saphire_load_obj(rc_fname
+                , pipeout, pipein, STDERR_FILENO);
+            sRFd_delete(pipein);
+            sWFd_flash(pipeout);
+            sWFd_delete(pipeout);
 
             if(rcode < 0) {
-                fprintf(stderr, "%s\n", gErrMsg);
+                fprintf(stderr, "%s\n", string_c_str(gErrMsg));
                 exit(1);
             }
         }
         else {
-            fprintf(stderr, "can't find %s/mfiler3.kio file\n", SYSCONFDIR);
+            fprintf(stderr, "can't find %s/mfiler3.sao file\n", SYSCONFDIR);
             exit(1);
         }
     }
@@ -226,10 +240,15 @@ static void read_rc_file()
     sprintf(rc_fname, "%s/mfiler3.ksh", gHomeDir);
 
     if(access(rc_fname, R_OK) == 0) {
-        int rcode = kitutuki_load(rc_fname
-            , STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+        sRFd* pipein = sRFd_new(STDIN_FILENO);
+        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        int rcode = saphire_load(rc_fname
+            , pipeout, pipein, STDERR_FILENO);
+        sRFd_delete(pipein);
+        sWFd_flash(pipeout);
+        sWFd_delete(pipeout);
         if(rcode < 0) {
-            fprintf(stderr, "%s\n", gErrMsg);
+            fprintf(stderr, "%s\n", string_c_str(gErrMsg));
             exit(1);
         }
     }
@@ -237,11 +256,16 @@ static void read_rc_file()
         sprintf(rc_fname,"%s/mfiler3.ksh", SYSCONFDIR);
 
         if(access(rc_fname, R_OK) == 0) {
-            int rcode = kitutuki_load(rc_fname
-                , STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+            sRFd* pipein = sRFd_new(STDIN_FILENO);
+            sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+            int rcode = saphire_load(rc_fname
+                , pipeout, pipein, STDERR_FILENO);
+            sRFd_delete(pipein);
+            sWFd_flash(pipeout);
+            sWFd_delete(pipeout);
 
             if(rcode < 0) {
-                fprintf(stderr, "%s\n", gErrMsg);
+                fprintf(stderr, "%s\n", string_c_str(gErrMsg));
                 exit(1);
             }
         }
@@ -283,7 +307,7 @@ static void sig_cont(int s)
 
 void set_signal_mfiler()
 {
-    kitutuki_set_signal();
+    saphire_set_signal();
 
     struct sigaction sa4;
 
@@ -464,8 +488,8 @@ static void usage()
 
 static void version()
 {
-    printf("mfiler3 version %s with shell scripting system kitutuki version %s.", getenv("VERSION"), getenv("KITUTUKI_VERSION"));
-    puts("This program is a traditional Japanese style 2pain file manager with a embedded shell scripting system \"kitutuki\". mfiler3 is developped by Daisuke Minato.");
+    printf("mfiler3 version %s with shell scripting system saphire version %s.", getenv("VERSION"), getenv("KITUTUKI_VERSION"));
+    puts("This program is a traditional Japanese style 2pain file manager with a embedded shell scripting system \"saphire\". mfiler3 is developped by Daisuke Minato.");
     puts("compiled with");
 
 #if defined(HAVE_MIGEMO_H)
@@ -474,7 +498,7 @@ static void version()
     puts("-migemo");
 #endif
     puts("+oniguruma");
-    puts("+kitutuki");
+    puts("+saphire");
     puts("+math");
     puts("+curses");
     
@@ -483,11 +507,12 @@ static void version()
 
 static void init_hooks()
 {
-    kitutuki_shell(" def mcd_hook { true }", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
-    kitutuki_shell(" def atexit_hook { true } ", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
-    kitutuki_shell(" def activate_hook { true }", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
-    kitutuki_shell(" def cursor_move_hook { true }", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
-    kitutuki_shell(" def cmdline_hook { true }", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+    sRFd* pipein = sRFd_new(STDIN_FILENO);
+    sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+    int rcode = saphire_shell(" def mcd_hook { true }; def atexit_hook { true }; def activate_hook { true }; def cursor_move_hook { true }; def cmdline_hook { true }", NULL, pipeout, pipein, STDERR_FILENO);
+    sRFd_delete(pipein);
+    sWFd_flash(pipeout);
+    sWFd_delete(pipeout);
 
 }
 
@@ -853,7 +878,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "3.0.8", 1);
+    setenv("VERSION", "4.0.1", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -915,6 +940,7 @@ int main(int argc, char* argv[])
             if(strcmp(argv[i], "--version") == 0) version();
 
             switch (argv[i][1]){
+/*
                 case 'E':
                     if(i+2 < argc && atoi(argv[i+1]) != 0) {
                         pid = atoi(argv[i+1]);
@@ -946,6 +972,7 @@ int main(int argc, char* argv[])
                         usage();
                     }
                     break;
+*/
 
                 case 'c':
                     if(i+1 < argc) {
@@ -1037,15 +1064,15 @@ int main(int argc, char* argv[])
         if(gTerminalKanjiCode == kTKUtf8) 
             setlocale(LC_CTYPE, "ja_JP.UTF-8");
 
-        kitutuki_init(kATOptC, FALSE, kRSObject); 
+        saphire_init(kATOptC, FALSE, kRSObject, FALSE); 
 
         if(pid != -1) {
             main_arg_e(send_cmd, pid);
         }
         else {
-            kitutuki_set_signal();
+            saphire_set_signal();
             string_obj* ret = STRING_NEW("");
-            kitutuki_shell3(ret, " pidof mfiler3", "pidof mfiler3");
+            saphire_shell3(ret, " pidof mfiler3", "pidof mfiler3");
 
             char* p = string_c_str(ret);
             int pid = 0;
@@ -1065,7 +1092,7 @@ int main(int argc, char* argv[])
             string_delete(ret);
         }
 
-        kitutuki_final();
+        saphire_final();
 
         return 0;
     }
@@ -1086,13 +1113,13 @@ int main(int argc, char* argv[])
     filer_init();
     mcurses_init(kTKUtf8);
     kanji_init();
-    kitutuki_init(kATConsoleApp, TRUE, kRSObject);
+    saphire_init(kATConsoleApp, TRUE, kRSObject, FALSE);
     cmdline_completion_init();
     commands_init();
 
     /// 初期キーバインドと初期フック ///
-    filer_add_keycommand(0, 'q', "*", "quit");
-    filer_add_keycommand(0, 3, "*", "quit"); // CTRL-C
+    filer_add_keycommand(0, 'q', "*", "quit", "system");
+    filer_add_keycommand(0, 3, "*", "quit", "system"); // CTRL-C
 
     /// ソケットの初期化 ///
     char soc_name[PATH_MAX];
@@ -1139,8 +1166,8 @@ int main(int argc, char* argv[])
     read_rc_file_compiled();
 
     /// リハッシュ ///
-    //kitutuki_job_done = ;
-    kitutuki_rehash();
+    //saphire_job_done = ;
+    saphire_rehash();
 
     /// モジュールの初期化(ランタイムスクリプト以降の方が良い奴 ///
     isearch_init();
@@ -1182,7 +1209,7 @@ int main(int argc, char* argv[])
         /// selectで入力待ち ///
         read_ok = mask;
         if(!mkbuf_exist()) {     // キーボードのバッファがないならselect
-            if(kitutuki_job_num() > 0) {
+            if(saphire_job_num() > 0) {
                 struct timeval tv;
                 tv.tv_sec = 5;
                 tv.tv_usec = 0;
@@ -1272,8 +1299,13 @@ int main(int argc, char* argv[])
                 mendwin();
                 mreset_tty();
 
-                kitutuki_set_signal();
-                kitutuki_shell(buf + 1, "mfiler3 -e", STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
+                saphire_set_signal();
+                sRFd* pipein = sRFd_new(STDIN_FILENO);
+                sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+                int rcode = saphire_shell(buf + 1, "mfiler3 -e", pipeout, pipein, STDERR_FILENO);
+                sRFd_delete(pipein);
+                sWFd_flash(pipeout);
+                sWFd_delete(pipeout);
 
                 putp(tigetstr("rev"));
                 printf("HIT ANY KEY");
@@ -1296,9 +1328,9 @@ int main(int argc, char* argv[])
                 mclear_immediately();
             }
             else if(buf[0] == 'e') {
-                kitutuki_set_signal();
+                saphire_set_signal();
                 string_obj* str = STRING_NEW("");
-                kitutuki_shell3(str, buf + 1, "mfiler3 -E");
+                saphire_shell3(str, buf + 1, "mfiler3 -E");
 
                 int pipe = open(pipe_name, O_WRONLY);
                 write(pipe, string_c_str(str), string_size(str) +1);
@@ -1309,12 +1341,12 @@ int main(int argc, char* argv[])
         }
 
         /// ジョブ処理 ///
-        kitutuki_wait_background_job();
+        saphire_wait_background_job();
     }
 
     /// ごみソケットとパイプの掃除 ///
     string_obj* ret = STRING_NEW("");
-    kitutuki_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets");
+    saphire_shell3(ret, " pidof mfiler3", "clean mfiler3 sockets");
 
     DIR* dir = opendir(gTempDir);
     if(dir == NULL) {
@@ -1363,8 +1395,13 @@ int main(int argc, char* argv[])
 
     /// フック呼び出し ///
     puts(""); // 見た目上のため
-    kitutuki_shell("atexit_hook", NULL, STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO);
-    kitutuki_kill_all_jobs();
+    sRFd* pipein = sRFd_new(STDIN_FILENO);
+    sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+    int rcode = saphire_shell("atexit_hook", NULL, pipeout, pipein, STDERR_FILENO);
+    sRFd_delete(pipein);
+    sWFd_flash(pipeout);
+    sWFd_delete(pipeout);
+    saphire_kill_all_jobs();
 
     /// モジュール解放 ///
     cmdline_final();
@@ -1374,7 +1411,7 @@ int main(int argc, char* argv[])
     kanji_final();
     menu_final();
     filer_final();
-    kitutuki_final();
+    saphire_final();
     commands_final();
 
     /// ソケット解放 ///
